@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package SVG::Estimate;
-$SVG::Estimate::VERSION = '1.0003';
+$SVG::Estimate::VERSION = '1.0004';
 use XML::Hash::LX;
 use XML::LibXML;
 use File::Slurp;
@@ -23,7 +23,7 @@ SVG::Estimate - Estimates the length of all the vectors in an SVG file.
 
 =head1 VERSION
 
-version 1.0003
+version 1.0004
 
 =head1 SYNOPSIS
 
@@ -294,7 +294,7 @@ sub sum {
         }
     }
     elsif (ref $elements eq 'HASH') {
-        foreach my $key (keys $elements) {
+        foreach my $key (keys %{ $elements }) {
             $self->sum($elements->{$key});
         }
     }
