@@ -1,5 +1,5 @@
 package SVG::Estimate::Circle;
-$SVG::Estimate::Circle::VERSION = '1.0003';
+$SVG::Estimate::Circle::VERSION = '1.0004';
 use Moo;
 use Math::Trig qw/pi/;
 
@@ -12,7 +12,7 @@ SVG::Estimate::Circle - Handles estimating circles.
 
 =head1 VERSION
 
-version 1.0003
+version 1.0004
 
 =head1 SYNOPSIS
 
@@ -93,6 +93,13 @@ sub BUILDARGS {
     return $args;
 }
 
+=head2 this_point ($args, $t)
+
+This class method is used to calculate a point on a circle, given it's relative position (C<$t>, ranging
+from 0 to 1, inclusive), and the radius and center of the circle from a hashref of C<$args> (C<r> and C<cx> and <cy>).
+
+=cut
+
 sub this_point {
     my $class = shift;
     my $args  = shift;
